# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

accessKey: Optional[str]
"""
The access key for API operations. You can retrieve this from the 'Security Management' section of the Alibaba Cloud
console.
"""

accountId: Optional[str]
"""
The account ID for some service API operations. You can retrieve this from the 'Security Settings' section of the
Alibaba Cloud console.
"""

assumeRole: Optional[str]

assumeRoleWithOidc: Optional[str]

clientConnectTimeout: Optional[int]
"""
The maximum timeout of the client connection server.
"""

clientReadTimeout: Optional[int]
"""
The maximum timeout of the client read request.
"""

configurationSource: Optional[str]

credentialsUri: Optional[str]
"""
The URI of sidecar credentials service.
"""

ecsRoleName: Optional[str]
"""
The RAM Role Name attached on a ECS instance for API operations. You can retrieve this from the 'Access Control' section
of the Alibaba Cloud console.
"""

endpoints: Optional[str]

fc: Optional[str]

logEndpoint: Optional[str]

maxRetryTimeout: Optional[int]
"""
The maximum retry timeout of the request.
"""

mnsEndpoint: Optional[str]

otsInstanceName: Optional[str]

profile: Optional[str]
"""
The profile for API operations. If not set, the default profile created with `aliyun configure` will be used.
"""

protocol: Optional[str]

region: Optional[str]
"""
The region where Alibaba Cloud operations will take place. Examples are cn-beijing, cn-hangzhou, eu-central-1, etc.
"""

secretKey: Optional[str]
"""
The secret key for API operations. You can retrieve this from the 'Security Management' section of the Alibaba Cloud
console.
"""

secureTransport: Optional[str]
"""
The security transport for the assume role invoking.
"""

securityToken: Optional[str]
"""
security token. A security token is only required if you are using Security Token Service.
"""

securityTransport: Optional[str]

sharedCredentialsFile: Optional[str]
"""
The path to the shared credentials file. If not set this defaults to ~/.aliyun/config.json
"""

signVersion: Optional[str]

skipRegionValidation: Optional[bool]
"""
Skip static validation of region ID. Used by users of alternative AlibabaCloud-like APIs or users w/ access to regions
that are not public (yet).
"""

sourceIp: Optional[str]
"""
The source ip for the assume role invoking.
"""

