# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTlsCipherPoliciesResult',
    'AwaitableGetTlsCipherPoliciesResult',
    'get_tls_cipher_policies',
    'get_tls_cipher_policies_output',
]

@pulumi.output_type
class GetTlsCipherPoliciesResult:
    """
    A collection of values returned by getTlsCipherPolicies.
    """
    def __init__(__self__, id=None, ids=None, include_listener=None, name_regex=None, names=None, output_file=None, policies=None, status=None, tls_cipher_policy_name=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if include_listener and not isinstance(include_listener, bool):
            raise TypeError("Expected argument 'include_listener' to be a bool")
        pulumi.set(__self__, "include_listener", include_listener)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if policies and not isinstance(policies, list):
            raise TypeError("Expected argument 'policies' to be a list")
        pulumi.set(__self__, "policies", policies)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tls_cipher_policy_name and not isinstance(tls_cipher_policy_name, str):
            raise TypeError("Expected argument 'tls_cipher_policy_name' to be a str")
        pulumi.set(__self__, "tls_cipher_policy_name", tls_cipher_policy_name)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="includeListener")
    def include_listener(self) -> Optional[bool]:
        return pulumi.get(self, "include_listener")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def policies(self) -> Sequence['outputs.GetTlsCipherPoliciesPolicyResult']:
        return pulumi.get(self, "policies")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="tlsCipherPolicyName")
    def tls_cipher_policy_name(self) -> Optional[str]:
        return pulumi.get(self, "tls_cipher_policy_name")


class AwaitableGetTlsCipherPoliciesResult(GetTlsCipherPoliciesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTlsCipherPoliciesResult(
            id=self.id,
            ids=self.ids,
            include_listener=self.include_listener,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            policies=self.policies,
            status=self.status,
            tls_cipher_policy_name=self.tls_cipher_policy_name)


def get_tls_cipher_policies(ids: Optional[Sequence[str]] = None,
                            include_listener: Optional[bool] = None,
                            name_regex: Optional[str] = None,
                            output_file: Optional[str] = None,
                            status: Optional[str] = None,
                            tls_cipher_policy_name: Optional[str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTlsCipherPoliciesResult:
    """
    This data source provides the Slb Tls Cipher Policies of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.135.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.slb.get_tls_cipher_policies(ids=[
        "example_value-1",
        "example_value-2",
    ])
    pulumi.export("slbTlsCipherPolicyId1", ids.policies[0].id)
    name_regex = alicloud.slb.get_tls_cipher_policies(name_regex="^My-TlsCipherPolicy")
    pulumi.export("slbTlsCipherPolicyId2", name_regex.policies[0].id)
    ```


    :param Sequence[str] ids: A list of Tls Cipher Policy IDs.
    :param bool include_listener: The include listener.
    :param str name_regex: A regex string to filter results by Tls Cipher Policy name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: TLS policy instance state. Valid values: `configuring`, `normal`.
    :param str tls_cipher_policy_name: TLS policy name. Length is from 2 to 128, or in both the English and Chinese characters must be with an uppercase/lowercase letter or a Chinese character and the beginning, may contain numbers, in dot `.`, underscore `_` or dash `-`.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['includeListener'] = include_listener
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    __args__['tlsCipherPolicyName'] = tls_cipher_policy_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:slb/getTlsCipherPolicies:getTlsCipherPolicies', __args__, opts=opts, typ=GetTlsCipherPoliciesResult).value

    return AwaitableGetTlsCipherPoliciesResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        include_listener=pulumi.get(__ret__, 'include_listener'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        policies=pulumi.get(__ret__, 'policies'),
        status=pulumi.get(__ret__, 'status'),
        tls_cipher_policy_name=pulumi.get(__ret__, 'tls_cipher_policy_name'))
def get_tls_cipher_policies_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                   include_listener: Optional[pulumi.Input[Optional[bool]]] = None,
                                   name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                                   output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                   status: Optional[pulumi.Input[Optional[str]]] = None,
                                   tls_cipher_policy_name: Optional[pulumi.Input[Optional[str]]] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetTlsCipherPoliciesResult]:
    """
    This data source provides the Slb Tls Cipher Policies of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.135.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.slb.get_tls_cipher_policies(ids=[
        "example_value-1",
        "example_value-2",
    ])
    pulumi.export("slbTlsCipherPolicyId1", ids.policies[0].id)
    name_regex = alicloud.slb.get_tls_cipher_policies(name_regex="^My-TlsCipherPolicy")
    pulumi.export("slbTlsCipherPolicyId2", name_regex.policies[0].id)
    ```


    :param Sequence[str] ids: A list of Tls Cipher Policy IDs.
    :param bool include_listener: The include listener.
    :param str name_regex: A regex string to filter results by Tls Cipher Policy name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: TLS policy instance state. Valid values: `configuring`, `normal`.
    :param str tls_cipher_policy_name: TLS policy name. Length is from 2 to 128, or in both the English and Chinese characters must be with an uppercase/lowercase letter or a Chinese character and the beginning, may contain numbers, in dot `.`, underscore `_` or dash `-`.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['includeListener'] = include_listener
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    __args__['tlsCipherPolicyName'] = tls_cipher_policy_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:slb/getTlsCipherPolicies:getTlsCipherPolicies', __args__, opts=opts, typ=GetTlsCipherPoliciesResult)
    return __ret__.apply(lambda __response__: GetTlsCipherPoliciesResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        include_listener=pulumi.get(__response__, 'include_listener'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        policies=pulumi.get(__response__, 'policies'),
        status=pulumi.get(__response__, 'status'),
        tls_cipher_policy_name=pulumi.get(__response__, 'tls_cipher_policy_name')))
