# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetEndpointGroupIpAddressCidrBlocksResult',
    'AwaitableGetEndpointGroupIpAddressCidrBlocksResult',
    'get_endpoint_group_ip_address_cidr_blocks',
    'get_endpoint_group_ip_address_cidr_blocks_output',
]

@pulumi.output_type
class GetEndpointGroupIpAddressCidrBlocksResult:
    """
    A collection of values returned by getEndpointGroupIpAddressCidrBlocks.
    """
    def __init__(__self__, accelerator_id=None, endpoint_group_ip_address_cidr_blocks=None, endpoint_group_region=None, id=None, output_file=None):
        if accelerator_id and not isinstance(accelerator_id, str):
            raise TypeError("Expected argument 'accelerator_id' to be a str")
        pulumi.set(__self__, "accelerator_id", accelerator_id)
        if endpoint_group_ip_address_cidr_blocks and not isinstance(endpoint_group_ip_address_cidr_blocks, list):
            raise TypeError("Expected argument 'endpoint_group_ip_address_cidr_blocks' to be a list")
        pulumi.set(__self__, "endpoint_group_ip_address_cidr_blocks", endpoint_group_ip_address_cidr_blocks)
        if endpoint_group_region and not isinstance(endpoint_group_region, str):
            raise TypeError("Expected argument 'endpoint_group_region' to be a str")
        pulumi.set(__self__, "endpoint_group_region", endpoint_group_region)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter(name="acceleratorId")
    def accelerator_id(self) -> Optional[str]:
        return pulumi.get(self, "accelerator_id")

    @property
    @pulumi.getter(name="endpointGroupIpAddressCidrBlocks")
    def endpoint_group_ip_address_cidr_blocks(self) -> Sequence['outputs.GetEndpointGroupIpAddressCidrBlocksEndpointGroupIpAddressCidrBlockResult']:
        """
        A list of Endpoint Group Ip Address Cidr Blocks. Each element contains the following attributes:
        """
        return pulumi.get(self, "endpoint_group_ip_address_cidr_blocks")

    @property
    @pulumi.getter(name="endpointGroupRegion")
    def endpoint_group_region(self) -> str:
        """
        The region ID of the endpoint group.
        """
        return pulumi.get(self, "endpoint_group_region")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")


class AwaitableGetEndpointGroupIpAddressCidrBlocksResult(GetEndpointGroupIpAddressCidrBlocksResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEndpointGroupIpAddressCidrBlocksResult(
            accelerator_id=self.accelerator_id,
            endpoint_group_ip_address_cidr_blocks=self.endpoint_group_ip_address_cidr_blocks,
            endpoint_group_region=self.endpoint_group_region,
            id=self.id,
            output_file=self.output_file)


def get_endpoint_group_ip_address_cidr_blocks(accelerator_id: Optional[str] = None,
                                              endpoint_group_region: Optional[str] = None,
                                              output_file: Optional[str] = None,
                                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEndpointGroupIpAddressCidrBlocksResult:
    """
    This data source provides the Global Accelerator (GA) Endpoint Group Ip Address Cidr Blocks of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.213.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.ga.get_endpoint_group_ip_address_cidr_blocks(endpoint_group_region="cn-hangzhou")
    pulumi.export("gaEndpointGroupIpAddressCidrBlocksEndpointGroupRegion", default.endpoint_group_ip_address_cidr_blocks[0].endpoint_group_region)
    ```


    :param str accelerator_id: The ID of the Global Accelerator (GA) instance.
    :param str endpoint_group_region: The region ID of the endpoint group.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['acceleratorId'] = accelerator_id
    __args__['endpointGroupRegion'] = endpoint_group_region
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ga/getEndpointGroupIpAddressCidrBlocks:getEndpointGroupIpAddressCidrBlocks', __args__, opts=opts, typ=GetEndpointGroupIpAddressCidrBlocksResult).value

    return AwaitableGetEndpointGroupIpAddressCidrBlocksResult(
        accelerator_id=pulumi.get(__ret__, 'accelerator_id'),
        endpoint_group_ip_address_cidr_blocks=pulumi.get(__ret__, 'endpoint_group_ip_address_cidr_blocks'),
        endpoint_group_region=pulumi.get(__ret__, 'endpoint_group_region'),
        id=pulumi.get(__ret__, 'id'),
        output_file=pulumi.get(__ret__, 'output_file'))
def get_endpoint_group_ip_address_cidr_blocks_output(accelerator_id: Optional[pulumi.Input[Optional[str]]] = None,
                                                     endpoint_group_region: Optional[pulumi.Input[str]] = None,
                                                     output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEndpointGroupIpAddressCidrBlocksResult]:
    """
    This data source provides the Global Accelerator (GA) Endpoint Group Ip Address Cidr Blocks of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.213.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.ga.get_endpoint_group_ip_address_cidr_blocks(endpoint_group_region="cn-hangzhou")
    pulumi.export("gaEndpointGroupIpAddressCidrBlocksEndpointGroupRegion", default.endpoint_group_ip_address_cidr_blocks[0].endpoint_group_region)
    ```


    :param str accelerator_id: The ID of the Global Accelerator (GA) instance.
    :param str endpoint_group_region: The region ID of the endpoint group.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['acceleratorId'] = accelerator_id
    __args__['endpointGroupRegion'] = endpoint_group_region
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:ga/getEndpointGroupIpAddressCidrBlocks:getEndpointGroupIpAddressCidrBlocks', __args__, opts=opts, typ=GetEndpointGroupIpAddressCidrBlocksResult)
    return __ret__.apply(lambda __response__: GetEndpointGroupIpAddressCidrBlocksResult(
        accelerator_id=pulumi.get(__response__, 'accelerator_id'),
        endpoint_group_ip_address_cidr_blocks=pulumi.get(__response__, 'endpoint_group_ip_address_cidr_blocks'),
        endpoint_group_region=pulumi.get(__response__, 'endpoint_group_region'),
        id=pulumi.get(__response__, 'id'),
        output_file=pulumi.get(__response__, 'output_file')))
