# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EcsSessionManagerStatusArgs', 'EcsSessionManagerStatus']

@pulumi.input_type
class EcsSessionManagerStatusArgs:
    def __init__(__self__, *,
                 session_manager_status_name: pulumi.Input[str],
                 status: pulumi.Input[str]):
        """
        The set of arguments for constructing a EcsSessionManagerStatus resource.
        :param pulumi.Input[str] session_manager_status_name: The name of the resource. Valid values: `sessionManagerStatus`.
        :param pulumi.Input[str] status: The status of the resource. Valid values: `Disabled`, `Enabled`.
        """
        pulumi.set(__self__, "session_manager_status_name", session_manager_status_name)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="sessionManagerStatusName")
    def session_manager_status_name(self) -> pulumi.Input[str]:
        """
        The name of the resource. Valid values: `sessionManagerStatus`.
        """
        return pulumi.get(self, "session_manager_status_name")

    @session_manager_status_name.setter
    def session_manager_status_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "session_manager_status_name", value)

    @property
    @pulumi.getter
    def status(self) -> pulumi.Input[str]:
        """
        The status of the resource. Valid values: `Disabled`, `Enabled`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: pulumi.Input[str]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _EcsSessionManagerStatusState:
    def __init__(__self__, *,
                 session_manager_status_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering EcsSessionManagerStatus resources.
        :param pulumi.Input[str] session_manager_status_name: The name of the resource. Valid values: `sessionManagerStatus`.
        :param pulumi.Input[str] status: The status of the resource. Valid values: `Disabled`, `Enabled`.
        """
        if session_manager_status_name is not None:
            pulumi.set(__self__, "session_manager_status_name", session_manager_status_name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="sessionManagerStatusName")
    def session_manager_status_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource. Valid values: `sessionManagerStatus`.
        """
        return pulumi.get(self, "session_manager_status_name")

    @session_manager_status_name.setter
    def session_manager_status_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "session_manager_status_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource. Valid values: `Disabled`, `Enabled`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class EcsSessionManagerStatus(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 session_manager_status_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a ECS Session Manager Status resource.

        For information about ECS Session Manager Status and how to use it, see [What is Session Manager Status](https://www.alibabacloud.com/help/zh/doc-detail/337915.html).

        > **NOTE:** Available in v1.148.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.ecs.EcsSessionManagerStatus("default",
            session_manager_status_name="sessionManagerStatus",
            status="Disabled")
        ```

        ## Import

        ECS Session Manager Status can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ecs/ecsSessionManagerStatus:EcsSessionManagerStatus example <session_manager_status_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] session_manager_status_name: The name of the resource. Valid values: `sessionManagerStatus`.
        :param pulumi.Input[str] status: The status of the resource. Valid values: `Disabled`, `Enabled`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EcsSessionManagerStatusArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ECS Session Manager Status resource.

        For information about ECS Session Manager Status and how to use it, see [What is Session Manager Status](https://www.alibabacloud.com/help/zh/doc-detail/337915.html).

        > **NOTE:** Available in v1.148.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.ecs.EcsSessionManagerStatus("default",
            session_manager_status_name="sessionManagerStatus",
            status="Disabled")
        ```

        ## Import

        ECS Session Manager Status can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ecs/ecsSessionManagerStatus:EcsSessionManagerStatus example <session_manager_status_name>
        ```

        :param str resource_name: The name of the resource.
        :param EcsSessionManagerStatusArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EcsSessionManagerStatusArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 session_manager_status_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EcsSessionManagerStatusArgs.__new__(EcsSessionManagerStatusArgs)

            if session_manager_status_name is None and not opts.urn:
                raise TypeError("Missing required property 'session_manager_status_name'")
            __props__.__dict__["session_manager_status_name"] = session_manager_status_name
            if status is None and not opts.urn:
                raise TypeError("Missing required property 'status'")
            __props__.__dict__["status"] = status
        super(EcsSessionManagerStatus, __self__).__init__(
            'alicloud:ecs/ecsSessionManagerStatus:EcsSessionManagerStatus',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            session_manager_status_name: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'EcsSessionManagerStatus':
        """
        Get an existing EcsSessionManagerStatus resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] session_manager_status_name: The name of the resource. Valid values: `sessionManagerStatus`.
        :param pulumi.Input[str] status: The status of the resource. Valid values: `Disabled`, `Enabled`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EcsSessionManagerStatusState.__new__(_EcsSessionManagerStatusState)

        __props__.__dict__["session_manager_status_name"] = session_manager_status_name
        __props__.__dict__["status"] = status
        return EcsSessionManagerStatus(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="sessionManagerStatusName")
    def session_manager_status_name(self) -> pulumi.Output[str]:
        """
        The name of the resource. Valid values: `sessionManagerStatus`.
        """
        return pulumi.get(self, "session_manager_status_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource. Valid values: `Disabled`, `Enabled`.
        """
        return pulumi.get(self, "status")

