# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['TemplateServiceArgs', 'TemplateService']

@pulumi.input_type
class TemplateServiceArgs:
    def __init__(__self__, *,
                 service_status: pulumi.Input[int]):
        """
        The set of arguments for constructing a TemplateService resource.
        :param pulumi.Input[int] service_status: Status of the quota template. Valid values:
               - `-1`: disabled.
        """
        pulumi.set(__self__, "service_status", service_status)

    @property
    @pulumi.getter(name="serviceStatus")
    def service_status(self) -> pulumi.Input[int]:
        """
        Status of the quota template. Valid values:
        - `-1`: disabled.
        """
        return pulumi.get(self, "service_status")

    @service_status.setter
    def service_status(self, value: pulumi.Input[int]):
        pulumi.set(self, "service_status", value)


@pulumi.input_type
class _TemplateServiceState:
    def __init__(__self__, *,
                 service_status: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering TemplateService resources.
        :param pulumi.Input[int] service_status: Status of the quota template. Valid values:
               - `-1`: disabled.
        """
        if service_status is not None:
            pulumi.set(__self__, "service_status", service_status)

    @property
    @pulumi.getter(name="serviceStatus")
    def service_status(self) -> Optional[pulumi.Input[int]]:
        """
        Status of the quota template. Valid values:
        - `-1`: disabled.
        """
        return pulumi.get(self, "service_status")

    @service_status.setter
    def service_status(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "service_status", value)


class TemplateService(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 service_status: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        ## Import

        Quotas Template Service can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:quotas/templateService:TemplateService example
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] service_status: Status of the quota template. Valid values:
               - `-1`: disabled.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TemplateServiceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Quotas Template Service can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:quotas/templateService:TemplateService example
        ```

        :param str resource_name: The name of the resource.
        :param TemplateServiceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TemplateServiceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 service_status: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TemplateServiceArgs.__new__(TemplateServiceArgs)

            if service_status is None and not opts.urn:
                raise TypeError("Missing required property 'service_status'")
            __props__.__dict__["service_status"] = service_status
        super(TemplateService, __self__).__init__(
            'alicloud:quotas/templateService:TemplateService',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            service_status: Optional[pulumi.Input[int]] = None) -> 'TemplateService':
        """
        Get an existing TemplateService resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] service_status: Status of the quota template. Valid values:
               - `-1`: disabled.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TemplateServiceState.__new__(_TemplateServiceState)

        __props__.__dict__["service_status"] = service_status
        return TemplateService(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="serviceStatus")
    def service_status(self) -> pulumi.Output[int]:
        """
        Status of the quota template. Valid values:
        - `-1`: disabled.
        """
        return pulumi.get(self, "service_status")

