# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'DbClusterDbClusterAccessWhiteListArgs',
    'DbClusterDbClusterAccessWhiteListArgsDict',
    'DbClusterMultiZoneVswitchListArgs',
    'DbClusterMultiZoneVswitchListArgsDict',
]

MYPY = False

if not MYPY:
    class DbClusterDbClusterAccessWhiteListArgsDict(TypedDict):
        db_cluster_ip_array_attribute: NotRequired[pulumi.Input[str]]
        """
        Field `db_cluster_ip_array_attribute` has been removed from provider.
        """
        db_cluster_ip_array_name: NotRequired[pulumi.Input[str]]
        """
        Whitelist group name.
        """
        security_ip_list: NotRequired[pulumi.Input[str]]
        """
        The IP address list under the whitelist group.
        """
elif False:
    DbClusterDbClusterAccessWhiteListArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DbClusterDbClusterAccessWhiteListArgs:
    def __init__(__self__, *,
                 db_cluster_ip_array_attribute: Optional[pulumi.Input[str]] = None,
                 db_cluster_ip_array_name: Optional[pulumi.Input[str]] = None,
                 security_ip_list: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] db_cluster_ip_array_attribute: Field `db_cluster_ip_array_attribute` has been removed from provider.
        :param pulumi.Input[str] db_cluster_ip_array_name: Whitelist group name.
        :param pulumi.Input[str] security_ip_list: The IP address list under the whitelist group.
        """
        if db_cluster_ip_array_attribute is not None:
            pulumi.set(__self__, "db_cluster_ip_array_attribute", db_cluster_ip_array_attribute)
        if db_cluster_ip_array_name is not None:
            pulumi.set(__self__, "db_cluster_ip_array_name", db_cluster_ip_array_name)
        if security_ip_list is not None:
            pulumi.set(__self__, "security_ip_list", security_ip_list)

    @property
    @pulumi.getter(name="dbClusterIpArrayAttribute")
    def db_cluster_ip_array_attribute(self) -> Optional[pulumi.Input[str]]:
        """
        Field `db_cluster_ip_array_attribute` has been removed from provider.
        """
        return pulumi.get(self, "db_cluster_ip_array_attribute")

    @db_cluster_ip_array_attribute.setter
    def db_cluster_ip_array_attribute(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "db_cluster_ip_array_attribute", value)

    @property
    @pulumi.getter(name="dbClusterIpArrayName")
    def db_cluster_ip_array_name(self) -> Optional[pulumi.Input[str]]:
        """
        Whitelist group name.
        """
        return pulumi.get(self, "db_cluster_ip_array_name")

    @db_cluster_ip_array_name.setter
    def db_cluster_ip_array_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "db_cluster_ip_array_name", value)

    @property
    @pulumi.getter(name="securityIpList")
    def security_ip_list(self) -> Optional[pulumi.Input[str]]:
        """
        The IP address list under the whitelist group.
        """
        return pulumi.get(self, "security_ip_list")

    @security_ip_list.setter
    def security_ip_list(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "security_ip_list", value)


if not MYPY:
    class DbClusterMultiZoneVswitchListArgsDict(TypedDict):
        vswitch_id: pulumi.Input[str]
        """
        The ID of the vswitch.
        """
        zone_id: NotRequired[pulumi.Input[str]]
        """
        The zone ID of the vswitch.
        """
elif False:
    DbClusterMultiZoneVswitchListArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DbClusterMultiZoneVswitchListArgs:
    def __init__(__self__, *,
                 vswitch_id: pulumi.Input[str],
                 zone_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] vswitch_id: The ID of the vswitch.
        :param pulumi.Input[str] zone_id: The zone ID of the vswitch.
        """
        pulumi.set(__self__, "vswitch_id", vswitch_id)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Input[str]:
        """
        The ID of the vswitch.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vswitch_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[str]]:
        """
        The zone ID of the vswitch.
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "zone_id", value)


