# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetInstancesInstanceResult',
]

@pulumi.output_type
class GetInstancesInstanceResult(dict):
    def __init__(__self__, *,
                 client_instance_id: str,
                 client_instance_name: str,
                 client_instance_type: str,
                 id: str,
                 instance_id: str,
                 instance_name: str,
                 instance_type: str,
                 status: str,
                 zone_id: str):
        """
        :param str client_instance_id: The ID of the ECS instance to be bound.
        :param str client_instance_name: The name of the ECS instance bound to the EAIS instance.
        :param str client_instance_type: The type of the ECS instance bound to the EAIS instance.
        :param str id: The ID of the Instance.
        :param str instance_id: The ID of the resource.
        :param str instance_name: The name of the resource.
        :param str instance_type: The type of the resource. Valid values: `eais.ei-a6.4xlarge`, `eais.ei-a6.2xlarge`, `eais.ei-a6.xlarge`, `eais.ei-a6.large`, `eais.ei-a6.medium`.
        :param str status: The status of the resource. Valid values: `Attaching`, `Available`, `Detaching`, `InUse`, `Starting`, `Unavailable`.
        :param str zone_id: The ID of the region to which the EAIS instance belongs.
        """
        pulumi.set(__self__, "client_instance_id", client_instance_id)
        pulumi.set(__self__, "client_instance_name", client_instance_name)
        pulumi.set(__self__, "client_instance_type", client_instance_type)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "instance_name", instance_name)
        pulumi.set(__self__, "instance_type", instance_type)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="clientInstanceId")
    def client_instance_id(self) -> str:
        """
        The ID of the ECS instance to be bound.
        """
        return pulumi.get(self, "client_instance_id")

    @property
    @pulumi.getter(name="clientInstanceName")
    def client_instance_name(self) -> str:
        """
        The name of the ECS instance bound to the EAIS instance.
        """
        return pulumi.get(self, "client_instance_name")

    @property
    @pulumi.getter(name="clientInstanceType")
    def client_instance_type(self) -> str:
        """
        The type of the ECS instance bound to the EAIS instance.
        """
        return pulumi.get(self, "client_instance_type")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Instance.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        The ID of the resource.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> str:
        """
        The name of the resource.
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> str:
        """
        The type of the resource. Valid values: `eais.ei-a6.4xlarge`, `eais.ei-a6.2xlarge`, `eais.ei-a6.xlarge`, `eais.ei-a6.large`, `eais.ei-a6.medium`.
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the resource. Valid values: `Attaching`, `Available`, `Detaching`, `InUse`, `Starting`, `Unavailable`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> str:
        """
        The ID of the region to which the EAIS instance belongs.
        """
        return pulumi.get(self, "zone_id")


