# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ReplicaGroupDrillArgs', 'ReplicaGroupDrill']

@pulumi.input_type
class ReplicaGroupDrillArgs:
    def __init__(__self__, *,
                 group_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a ReplicaGroupDrill resource.
        :param pulumi.Input[str] group_id: The ID of the replication group. You can use the describediskreplicaggroups interface to query the asynchronous replication group list to obtain the value of the replication group ID input parameter.
        """
        pulumi.set(__self__, "group_id", group_id)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Input[str]:
        """
        The ID of the replication group. You can use the describediskreplicaggroups interface to query the asynchronous replication group list to obtain the value of the replication group ID input parameter.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "group_id", value)


@pulumi.input_type
class _ReplicaGroupDrillState:
    def __init__(__self__, *,
                 group_id: Optional[pulumi.Input[str]] = None,
                 replica_group_drill_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ReplicaGroupDrill resources.
        :param pulumi.Input[str] group_id: The ID of the replication group. You can use the describediskreplicaggroups interface to query the asynchronous replication group list to obtain the value of the replication group ID input parameter.
        :param pulumi.Input[str] replica_group_drill_id: The first ID of the resource.
        :param pulumi.Input[str] status: Walkthrough status. _failed: Execution failed._failed: Cleanup failed.
        """
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if replica_group_drill_id is not None:
            pulumi.set(__self__, "replica_group_drill_id", replica_group_drill_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the replication group. You can use the describediskreplicaggroups interface to query the asynchronous replication group list to obtain the value of the replication group ID input parameter.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="replicaGroupDrillId")
    def replica_group_drill_id(self) -> Optional[pulumi.Input[str]]:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "replica_group_drill_id")

    @replica_group_drill_id.setter
    def replica_group_drill_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "replica_group_drill_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Walkthrough status. _failed: Execution failed._failed: Cleanup failed.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class ReplicaGroupDrill(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a EBS Replica Group Drill resource.

        For information about EBS Replica Group Drill and how to use it, see [What is Replica Group Drill](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.215.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.ebs.ReplicaGroupDrill("default", group_id="pg-m1H9aaOUIGsDUwgZ")
        ```

        ## Import

        EBS Replica Group Drill can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ebs/replicaGroupDrill:ReplicaGroupDrill example <group_id>:<replica_group_drill_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] group_id: The ID of the replication group. You can use the describediskreplicaggroups interface to query the asynchronous replication group list to obtain the value of the replication group ID input parameter.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ReplicaGroupDrillArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a EBS Replica Group Drill resource.

        For information about EBS Replica Group Drill and how to use it, see [What is Replica Group Drill](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.215.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.ebs.ReplicaGroupDrill("default", group_id="pg-m1H9aaOUIGsDUwgZ")
        ```

        ## Import

        EBS Replica Group Drill can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ebs/replicaGroupDrill:ReplicaGroupDrill example <group_id>:<replica_group_drill_id>
        ```

        :param str resource_name: The name of the resource.
        :param ReplicaGroupDrillArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ReplicaGroupDrillArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ReplicaGroupDrillArgs.__new__(ReplicaGroupDrillArgs)

            if group_id is None and not opts.urn:
                raise TypeError("Missing required property 'group_id'")
            __props__.__dict__["group_id"] = group_id
            __props__.__dict__["replica_group_drill_id"] = None
            __props__.__dict__["status"] = None
        super(ReplicaGroupDrill, __self__).__init__(
            'alicloud:ebs/replicaGroupDrill:ReplicaGroupDrill',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            group_id: Optional[pulumi.Input[str]] = None,
            replica_group_drill_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'ReplicaGroupDrill':
        """
        Get an existing ReplicaGroupDrill resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] group_id: The ID of the replication group. You can use the describediskreplicaggroups interface to query the asynchronous replication group list to obtain the value of the replication group ID input parameter.
        :param pulumi.Input[str] replica_group_drill_id: The first ID of the resource.
        :param pulumi.Input[str] status: Walkthrough status. _failed: Execution failed._failed: Cleanup failed.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ReplicaGroupDrillState.__new__(_ReplicaGroupDrillState)

        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["replica_group_drill_id"] = replica_group_drill_id
        __props__.__dict__["status"] = status
        return ReplicaGroupDrill(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[str]:
        """
        The ID of the replication group. You can use the describediskreplicaggroups interface to query the asynchronous replication group list to obtain the value of the replication group ID input parameter.
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="replicaGroupDrillId")
    def replica_group_drill_id(self) -> pulumi.Output[str]:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "replica_group_drill_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Walkthrough status. _failed: Execution failed._failed: Cleanup failed.
        """
        return pulumi.get(self, "status")

